@@ -1,26 +1,14 @@
 /* This file is part of the KDE libraries
-   Copyright (C) 2009 Dario Freddi <drf at kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+ * SPDX-FileCopyrightText: 2009 Dario Freddi <drf at kde.org>
+ *
+ * SPDX-License-Identifier: LGPL-2.0-only
+ */
 
 #include "widgetbasedpoller.h"
 
-#include <QWidget>
-#include <QTimer>
 #include <QEvent>
+#include <QTimer>
+#include <QWindow>
 
 WidgetBasedPoller::WidgetBasedPoller(QObject *parent)
     : AbstractSystemPoller(parent)
@@ -40,13 +28,12 @@ bool WidgetBasedPoller::setUpPoller()
 {
     m_pollTimer = new QTimer(this);
 
-    //setup idle timer, with some smart polling
+    // setup idle timer, with some smart polling
     connect(m_pollTimer, &QTimer::timeout, this, &WidgetBasedPoller::poll);
 
-    // This code was taken from Lithium/KDE4Powersave
-    m_grabber = new QWidget(nullptr, Qt::X11BypassWindowManagerHint);
-    m_grabber->move(-1000, -1000);
-    m_grabber->setMouseTracking(true);
+    m_grabber = new QWindow();
+    m_grabber->setFlag(Qt::X11BypassWindowManagerHint);
+    m_grabber->setPosition(-1000, -1000);
     m_grabber->installEventFilter(this);
     m_grabber->setObjectName(QStringLiteral("KIdleGrabberWidget"));
 
@@ -72,8 +59,7 @@ void WidgetBasedPoller::addTimeout(int nextTimeout)
 
 bool WidgetBasedPoller::eventFilter(QObject *object, QEvent *event)
 {
-    if (object == m_grabber
-            && (event->type() == QEvent::MouseMove || event->type() == QEvent::KeyPress)) {
+    if (object == m_grabber && (event->type() == QEvent::MouseMove || event->type() == QEvent::KeyPress)) {
         detectedActivity();
         return true;
     } else if (object != m_grabber) {
@@ -83,29 +69,25 @@ bool WidgetBasedPoller::eventFilter(QObject *object, QEvent *event)
 
     // Otherwise, simply ignore it
     return false;
-
 }
 
 void WidgetBasedPoller::waitForActivity()
 {
-    // This code was taken from Lithium/KDE4Powersave
-
     m_grabber->show();
-    m_grabber->grabMouse();
-    m_grabber->grabKeyboard();
-
+    m_grabber->setMouseGrabEnabled(true);
+    m_grabber->setKeyboardGrabEnabled(true);
 }
 
 void WidgetBasedPoller::detectedActivity()
 {
     stopCatchingIdleEvents();
-    emit resumingFromIdle();
+    Q_EMIT resumingFromIdle();
 }
 
 void WidgetBasedPoller::releaseInputLock()
 {
-    m_grabber->releaseMouse();
-    m_grabber->releaseKeyboard();
+    m_grabber->setMouseGrabEnabled(false);
+    m_grabber->setKeyboardGrabEnabled(false);
     m_grabber->hide();
 }
 
@@ -114,23 +96,23 @@ int WidgetBasedPoller::poll()
     int idle = getIdleTime();
 
     // Check if we reached a timeout..
-    Q_FOREACH(int timeOut, m_timeouts) {
-        if ( ( timeOut - idle < 300 && timeOut >= idle ) || ( idle - timeOut < 300 && idle > timeOut ) ) {
+    for (int timeOut : qAsConst(m_timeouts)) {
+        if ((timeOut - idle < 300 && timeOut >= idle) || (idle - timeOut < 300 && idle > timeOut)) {
             // Bingo!
-            emit timeoutReached( timeOut );
+            Q_EMIT timeoutReached(timeOut);
         }
     }
 
     // Let's check the timer now!
     int mintime = 0;
 
-    Q_FOREACH (int i, m_timeouts) {
+    for (int i : qAsConst(m_timeouts)) {
         if (i > idle && (i < mintime || mintime == 0)) {
             mintime = i;
         }
     }
 
-    //qDebug() << "mintime " << mintime << "idle " << idle;
+    // qDebug() << "mintime " << mintime << "idle " << idle;
 
     if (mintime != 0) {
         m_pollTimer->start(mintime - idle);
@@ -161,4 +143,3 @@ void WidgetBasedPoller::stopCatchingIdleEvents()
 {
     releaseInputLock();
 }
-
